Auto Refresh

{$ 'Name' | translate $} | {$ 'Status' | translate $} | {$ 'Type' | translate $} | {$ 'Details' | translate $} | {$ 'Timestamp' | translate $} | {$ 'Show' | translate $} | {$ 'Delete' | translate $}
--- | --- | --- | --- | --- | --- | ---
{$template.name$} | {$template.status$} | {$template.type$} | {$template["status details"]$} | {$template.date | vitrageDate:templateList.dateFormat:templateList.timezone$} |  |